@@ -20,6 +20,11 @@
 #' @noRd
 create_layer <- function(LayerClass, object, args = list()) {
 
+  # force `object` before instantiating the layer, so pipe chains create layers
+  # in the the intutitively expected order.
+  # https://github.com/rstudio/keras/issues/1440
+  object <- if (missing(object)) NULL else object
+
   # Starting in Keras 3.1, constraints can't be simple callable functions, they
   # *must* inherit from keras.constraints.Constraint()
   args <- imap(args, function(arg, name) {
@@ -37,7 +42,7 @@ create_layer <- function(LayerClass, object, args = list()) {
   layer <- do.call(LayerClass, args)
 
   # compose if we have an `object`
-  if (missing(object) || is.null(object))
+  if (is.null(object))
     layer
   else
     invisible(compose_layer(object, layer))
@@ -65,7 +70,7 @@ compose_layer <- function(object, layer, ...) {
 
 # TODO: use formals(x) in py_to_r_wrapper.Layer() to construct a better wrapper fn
 # (( though, all layer.__call__ signatures are generally (...), unless user
-#     implemented __call__() directly insteald of call() ))
+#     implemented __call__() directly instead of call() ))
 
 # This is used for:
 # - ALL layer instances (custom and builtin) and
