@@ -269,6 +269,9 @@ function (object, x = NULL, y = NULL, ..., batch_size = NULL,
                                verbose = as_model_verbose_arg),
                           ignore = "object",
                           force = "verbose")
+
+    ## return_dict=TRUE because object$metrics_names returns wrong value
+    ## (e.g., "compile_metrics" instead of "mae")
     args[["return_dict"]] <- TRUE
 
     if(inherits(args$x, "tensorflow.python.data.ops.dataset_ops.DatasetV2") &&
@@ -276,6 +279,10 @@ function (object, x = NULL, y = NULL, ..., batch_size = NULL,
       stop("batch_size can not be specified with a TF Dataset")
 
     result <- do.call(object$evaluate, args)
+    # if (length(result) > 1L) { ## if return_dict=FALSE
+    #   result <- as.list(result)
+    #   names(result) <- object$metrics_names
+    # }
 
     tfruns::write_run_metadata("evaluation", unlist(result))
 
@@ -756,8 +763,16 @@ function (object, x, y = NULL, sample_weight = NULL, ...)
 {
     result <- object$test_on_batch(as_array(x),
                                    as_array(y),
-                                   as_array(sample_weight), ..., return_dict = TRUE)
-    if (is_scalar(result)) result[[1L]] else result
+                                   as_array(sample_weight), ...,
+                                   return_dict = TRUE)
+    # if (length(result) > 1L) {
+    #   result <- as.list(result)
+    #   names(result) <- object$metrics_names
+    # } else
+    if (is_scalar(result)) {
+      result <- result[[1L]]
+    }
+    result
 }
 
 # ---- test_on_batch ----
@@ -814,7 +829,15 @@ function (object, x, y = NULL, sample_weight = NULL, class_weight = NULL)
                                     as_array(sample_weight),
                                     class_weight = as_class_weight(class_weight),
                                     return_dict = TRUE)
-    if(is_scalar(result)) result[[1L]] else result
+    # if (length(result) > 1L) {
+    #   result <- as.list(result)
+    #   names(result) <- object$metrics_names
+    # } else
+    if (is_scalar(result)) {
+      result <- result[[1L]]
+    }
+
+    result
 }
 
 
@@ -895,7 +918,6 @@ function (object, x, y = NULL, sample_weight = NULL, class_weight = NULL)
 #' @export
 summary.keras.src.models.model.Model <- function(object, ...) {
     writeLines(f <- format.keras.src.models.model.Model(object, ...))
-  # TODO: knit_print...?
     invisible(f)
 }
 
@@ -909,6 +931,7 @@ function(x,
          expand_nested = FALSE,
          show_trainable = NA,
          ...,
+         # TODO: add force_ascii arg
          # force_ascii ... (impl in man/roxygen/meta.R)
          # width = getOption("width"),
          # rich = TRUE, ??
@@ -927,9 +950,6 @@ function(x,
       args$show_trainable <- built && as.logical(length(x$non_trainable_weights))
     }
 
-    # args$print_fn <- function(x, ...) {browser(); x}
-
-    # Do we need to check for model$built before calling summary?
     with_rich_config(
       out <- trimws(py_capture_output(do.call(x$summary, args)))
     )
