@@ -93,13 +93,16 @@
 #' automatically set a loss scale factor.
 #'
 #' @param gradient_accumulation_steps
-#' Int or `NULL`. If an int, model & optimizer
+#' Int or `NULL`. If an int, model and optimizer
 #' variables will not be updated at every step; instead they will be
 #' updated every `gradient_accumulation_steps` steps, using the average
 #' value of the gradients since the last update. This is known as
 #' "gradient accumulation". This can be useful
 #' when your batch size is very small, in order to reduce gradient
-#' noise at each update step.
+#' noise at each update step. EMA frequency will look at "accumulated"
+#' iterations value (optimizer steps // gradient_accumulation_steps).
+#' Learning rate schedules will look at "real" iterations value
+#' (optimizer steps).
 #'
 #' @param ...
 #' For forward/backward compatability.
@@ -913,6 +916,129 @@ function (learning_rate = 0.001, learning_rate_power = -0.5,
 }
 
 
+#' Optimizer that implements the Lamb algorithm.
+#'
+#' @description
+#' Lamb is a stochastic gradient descent method that
+#' uses layer-wise adaptive moments to adjusts the
+#' learning rate for each parameter based on the ratio of the
+#' norm of the weight to the norm of the gradient
+#' This helps to stabilize the training process and improves convergence
+#' especially for large batch sizes.
+#'
+#' # References
+#' - [Yang et al.](https://arxiv.org/pdf/1904.00962)
+#'
+#' @param learning_rate
+#' A float, a
+#' [`LearningRateSchedule()`] instance, or
+#' a callable that takes no arguments and returns the actual value to
+#' use. The learning rate. Defaults to `0.001`.
+#'
+#' @param beta_1
+#' A float value or a constant float tensor, or a callable
+#' that takes no arguments and returns the actual value to use. The
+#' exponential decay rate for the 1st moment estimates. Defaults to
+#' `0.9`.
+#'
+#' @param beta_2
+#' A float value or a constant float tensor, or a callable
+#' that takes no arguments and returns the actual value to use. The
+#' exponential decay rate for the 2nd moment estimates. Defaults to
+#' `0.999`.
+#'
+#' @param epsilon
+#' A small constant for numerical stability.
+#' Defaults to `1e-7`.
+#'
+#' @param name
+#' String. The name to use
+#' for momentum accumulator weights created by
+#' the optimizer.
+#'
+#' @param weight_decay
+#' Float. If set, weight decay is applied.
+#'
+#' @param clipnorm
+#' Float. If set, the gradient of each weight is individually
+#' clipped so that its norm is no higher than this value.
+#'
+#' @param clipvalue
+#' Float. If set, the gradient of each weight is clipped to be
+#' no higher than this value.
+#'
+#' @param global_clipnorm
+#' Float. If set, the gradient of all weights is clipped
+#' so that their global norm is no higher than this value.
+#'
+#' @param use_ema
+#' Boolean, defaults to `FALSE`.
+#' If `TRUE`, exponential moving average
+#' (EMA) is applied. EMA consists of computing an exponential moving
+#' average of the weights of the model (as the weight values change
+#' after each training batch), and periodically overwriting the
+#' weights with their moving average.
+#'
+#' @param ema_momentum
+#' Float, defaults to `0.99`. Only used if `use_ema = TRUE`.
+#' This is the momentum to use when computing
+#' the EMA of the model's weights:
+#' `new_average = ema_momentum * old_average + (1 - ema_momentum) * current_variable_value`.
+#'
+#' @param ema_overwrite_frequency
+#' Int or `NULL`, defaults to `NULL`. Only used if
+#' `use_ema = TRUE`. Every `ema_overwrite_frequency` steps of iterations,
+#' we overwrite the model variable by its moving average.
+#' If `NULL`, the optimizer
+#' does not overwrite model variables in the middle of training,
+#' and you need to explicitly overwrite the variables
+#' at the end of training by calling
+#' `optimizer$finalize_variable_values()` (which updates the model
+#' variables in-place). When using the built-in `fit()` training loop,
+#' this happens automatically after the last epoch,
+#' and you don't need to do anything.
+#'
+#' @param loss_scale_factor
+#' Float or `NULL`. If a float, the scale factor will
+#' be multiplied the loss before computing gradients, and the inverse
+#' of the scale factor will be multiplied by the gradients before
+#' updating variables. Useful for preventing underflow during
+#' mixed precision training. Alternately,
+#' [`optimizer_loss_scale()`] will
+#' automatically set a loss scale factor.
+#'
+#' @param gradient_accumulation_steps
+#' Int or `NULL`. If an int, model and optimizer
+#' variables will not be updated at every step; instead they will be
+#' updated every `gradient_accumulation_steps` steps, using the average
+#' value of the gradients since the last update. This is known as
+#' "gradient accumulation". This can be useful
+#' when your batch size is very small, in order to reduce gradient
+#' noise at each update step. EMA frequency will look at "accumulated"
+#' iterations value (optimizer steps // gradient_accumulation_steps).
+#' Learning rate schedules will look at "real" iterations value
+#' (optimizer steps).
+#'
+#' @param ...
+#' For forward/backward compatability.
+#'
+#' @export
+#' @family optimizers
+#' @returns an `Optimizer` instance
+#' @tether keras.optimizers.Lamb
+optimizer_lamb <-
+function (learning_rate = 0.001, beta_1 = 0.9, beta_2 = 0.999,
+    epsilon = 1e-07, weight_decay = NULL, clipnorm = NULL, clipvalue = NULL,
+    global_clipnorm = NULL, use_ema = FALSE, ema_momentum = 0.99,
+    ema_overwrite_frequency = NULL, loss_scale_factor = NULL,
+    gradient_accumulation_steps = NULL, name = "lamb", ...)
+{
+    args <- capture_args(list(ema_overwrite_frequency = as_integer,
+        gradient_accumulation_steps = as_integer))
+    do.call(keras$optimizers$Lamb, args)
+}
+
+
 #' Optimizer that implements the Lion algorithm.
 #'
 #' @description
